# Security Policy

## Supported Versions

| Version     | Supported          |
| ----------- | ------------------ |
| >= 4.11.2   | :white_check_mark: |
| < 4.11.2    | :x:                |

## Security contact information

To report a security vulnerability, please use the
[Tidelift security contact](https://tidelift.com/security).
Tidelift will coordinate the fix and disclosure.
